==> jonas-JONAS_4_6_4.tar.gz: jonas-JONAS_4_6_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/service/container/ContainerForm.java <==
/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer(s): Michel-Ange ANTON
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.service.container;

import java.util.ArrayList;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.webapp.jonasadmin.JonasAdminJmx;

public class ContainerForm extends ActionForm {

// --------------------------------------------------------- Properties variables

    private String path = null;
    private String filename = null;
    private String containerName = null;
    private int currentNumberOfMDBType = 0;
    private int currentNumberOfSBFType = 0;
    private int currentNumberOfBMPType = 0;
    private int currentNumberOfSBLType = 0;
    private int currentNumberOfCMPType = 0;
    private int currentNumberOfBeanType = 0;
    private ArrayList ejbs = new ArrayList();
    private boolean inEarCase = false;
    private String earPath = null;
    private String earFilename = null;

// --------------------------------------------------------- Public Methods

    /**
     * Reset all properties to their default values.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     */

    public void reset(ActionMapping mapping, HttpServletRequest request) {
        containerName = null;
        currentNumberOfMDBType = 0;
        currentNumberOfSBFType = 0;
        currentNumberOfBMPType = 0;
        currentNumberOfSBLType = 0;
        currentNumberOfCMPType = 0;
        currentNumberOfBeanType = 0;
        inEarCase = false;
        earPath = null;
        earFilename = null;
    }

    /**
     * Validate the properties that have been set from this HTTP request,
     * and return an <code>ActionErrors</code> object that encapsulates any
     * validation errors that have been found.  If no errors are found, return
     * <code>null</code> or an <code>ActionErrors</code> object with no
     * recorded error messages.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {
        ActionErrors oErrors = new ActionErrors();
        return oErrors;
    }

// --------------------------------------------------------- Properties Methods

    public String getFilename() {
        return filename;
    }

    public String getContainerName() {
        return containerName;
    }

    public int getCurrentNumberOfMDBType() {
        return currentNumberOfMDBType;
    }

    public int getCurrentNumberOfSBFType() {
        return currentNumberOfSBFType;
    }

    public int getCurrentNumberOfBMPType() {
        return currentNumberOfBMPType;
    }

    public int getCurrentNumberOfSBLType() {
        return currentNumberOfSBLType;
    }

    public int getCurrentNumberOfCMPType() {
        return currentNumberOfCMPType;
    }

    public int getCurrentNumberOfBeanType() {
        return currentNumberOfBeanType;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public void setContainerName(String containerName) {
        this.containerName = containerName;
    }

    public void setCurrentNumberOfMDBType(int currentNumberOfMDBType) {
        this.currentNumberOfMDBType = currentNumberOfMDBType;
    }

    public void setCurrentNumberOfSBFType(int currentNumberOfSBFType) {
        this.currentNumberOfSBFType = currentNumberOfSBFType;
    }

    public void setCurrentNumberOfBMPType(int currentNumberOfBMPType) {
        this.currentNumberOfBMPType = currentNumberOfBMPType;
    }

    public void setCurrentNumberOfSBLType(int currentNumberOfSBLType) {
        this.currentNumberOfSBLType = currentNumberOfSBLType;
    }

    public void setCurrentNumberOfCMPType(int currentNumberOfCMPType) {
        this.currentNumberOfCMPType = currentNumberOfCMPType;
    }

    public void setCurrentNumberOfBeanType(int currentNumberOfBeanType) {
        this.currentNumberOfBeanType = currentNumberOfBeanType;
    }

    public ArrayList getEjbs() {
        return ejbs;
    }

    public void setEjbs(ArrayList ejbs) {
        this.ejbs = ejbs;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public boolean isInEarCase() {
        return inEarCase;
    }

    public void setInEarCase(boolean inEarCase) {
        this.inEarCase = inEarCase;
    }

    public String getEarPath() {
        return earPath;
    }

    public void setEarPath(String p_EarPath) {
        earPath = null;
        earFilename = null;
        if (p_EarPath != null) {
            earPath = p_EarPath;
            earFilename = JonasAdminJmx.extractFilename(earPath);
        }
    }

    public String getEarFilename() {
        return earFilename;
    }

}

==> jonas-JONAS_4_10_6.tar.gz: jonas-JONAS_4_10_6/jonas/src/org/objectweb/jonas/webapp/jonasadmin/service/container/ContainerForm.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2008 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.service.container;

import java.util.ArrayList;
import java.util.List;

import javax.management.ObjectName;
import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.webapp.jonasadmin.Jlists;
import org.objectweb.jonas.webapp.jonasadmin.service.ModuleForm;

/**
 * @author Michel-Ange ANTON
 * @author Adriana Danes
 * @author S. Ali Tokmen, Malek Chahine: EJB statistics
 */
public class ContainerForm extends ModuleForm {

// --------------------------------------------------------- Properties variables

    private String path = null;
    private String filename = null;
    private String containerName = null;
    private int currentNumberOfMDBType = 0;
    private int currentNumberOfSBFType = 0;
    private int currentNumberOfBMPType = 0;
    private int currentNumberOfSBLType = 0;
    private int currentNumberOfCMPType = 0;
    private int currentNumberOfBeanType = 0;
    private boolean monitoringEnabled = false;
    private int warningThreshold = 0;
    private int numberOfCalls = 0;
    private long totalBusinessProcessingTime = 0;
    private long totalProcessingTime = 0;
    private long averageBusinessProcessingTime = 0;
    private long averageProcessingTime = 0;
    private ArrayList ejbs = new ArrayList();
    private String monitoringApplySettings = null;
    private ObjectName objectName= null;

// --------------------------------------------------------- Public Methods


    /**
     * Reset all properties to their default values.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     */

    public void reset(ActionMapping mapping, HttpServletRequest request) {
        containerName = null;
        currentNumberOfMDBType = 0;
        currentNumberOfSBFType = 0;
        currentNumberOfBMPType = 0;
        currentNumberOfSBLType = 0;
        currentNumberOfCMPType = 0;
        currentNumberOfBeanType = 0;
    }

    /**
     * Validate the properties that have been set from this HTTP request,
     * and return an <code>ActionErrors</code> object that encapsulates any
     * validation errors that have been found.  If no errors are found, return
     * <code>null</code> or an <code>ActionErrors</code> object with no
     * recorded error messages.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {
        ActionErrors oErrors = new ActionErrors();
        return oErrors;
    }

// --------------------------------------------------------- Properties Methods

    public String getFilename() {
        return filename;
    }

    public String getContainerName() {
        return containerName;
    }

    public int getCurrentNumberOfMDBType() {
        return currentNumberOfMDBType;
    }

    public int getCurrentNumberOfSBFType() {
        return currentNumberOfSBFType;
    }

    public int getCurrentNumberOfBMPType() {
        return currentNumberOfBMPType;
    }

    public int getCurrentNumberOfSBLType() {
        return currentNumberOfSBLType;
    }

    public int getCurrentNumberOfCMPType() {
        return currentNumberOfCMPType;
    }

    public int getCurrentNumberOfBeanType() {
        return currentNumberOfBeanType;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public void setContainerName(String containerName) {
        this.containerName = containerName;
    }

    public void setCurrentNumberOfMDBType(int currentNumberOfMDBType) {
        this.currentNumberOfMDBType = currentNumberOfMDBType;
    }

    public void setCurrentNumberOfSBFType(int currentNumberOfSBFType) {
        this.currentNumberOfSBFType = currentNumberOfSBFType;
    }

    public void setCurrentNumberOfBMPType(int currentNumberOfBMPType) {
        this.currentNumberOfBMPType = currentNumberOfBMPType;
    }

    public void setCurrentNumberOfSBLType(int currentNumberOfSBLType) {
        this.currentNumberOfSBLType = currentNumberOfSBLType;
    }

    public void setCurrentNumberOfCMPType(int currentNumberOfCMPType) {
        this.currentNumberOfCMPType = currentNumberOfCMPType;
    }

    public void setCurrentNumberOfBeanType(int currentNumberOfBeanType) {
        this.currentNumberOfBeanType = currentNumberOfBeanType;
    }

    public ArrayList getEjbs() {
        return ejbs;
    }

    public void setEjbs(ArrayList ejbs) {
        this.ejbs = ejbs;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public boolean getMonitoringEnabled() {
        return monitoringEnabled;
    }

    public void setMonitoringEnabled(boolean monitoringEnabled) {
        this.monitoringEnabled = monitoringEnabled;
    }

    public int getWarningThreshold() {
        return warningThreshold;
    }

    public void setWarningThreshold(int warningThreshold) {
        this.warningThreshold = warningThreshold;
    }

    public int getNumberOfCalls() {
        return numberOfCalls;
    }

    public void setNumberOfCalls(int numberOfCalls) {
        this.numberOfCalls = numberOfCalls;
    }

    public long getTotalBusinessProcessingTime() {
        return totalBusinessProcessingTime;
    }

    public void setTotalBusinessProcessingTime(long totalBusinessProcessingTime) {
        this.totalBusinessProcessingTime = totalBusinessProcessingTime;
    }

    public long getTotalProcessingTime() {
        return totalProcessingTime;
    }

    public void setTotalProcessingTime(long totalProcessingTime) {
        this.totalProcessingTime = totalProcessingTime;
    }

    public long getAverageBusinessProcessingTime() {
        return averageBusinessProcessingTime;
    }

    public void setAverageBusinessProcessingTime(long averageBusinessProcessingTime) {
        this.averageBusinessProcessingTime = averageBusinessProcessingTime;
    }

    public long getAverageProcessingTime() {
        return averageProcessingTime;
    }

    public void setAverageProcessingTime(long averageProcessingTime) {
        this.averageProcessingTime = averageProcessingTime;
    }

    public List getBooleanValues() {
        return Jlists.getBooleanValues();
    }

    public String getMonitoringApplySettings() {
        return monitoringApplySettings;
    }

    public void setMonitoringApplySettings(String monitoringApplySettings) {
        this.monitoringApplySettings = monitoringApplySettings;
    }
    
    public List getMonitoringApplySettingsValues() {
        return Jlists.getMonitoringApplySettingsValues();
    }

    public ObjectName getObjectName() {
        return objectName;
    }

    public void setObjectName(ObjectName objectName) {
        this.objectName = objectName;
    }
}
